============
Installation
============

Install using pip or easy_install. Nothing further is required.

If you'd like to install django-easyfilters so that you can also easily edit
the source code, you can use::

    pip install -e
    hg+ssh://hg@bitbucket.org/spookylukey/django-easyfilters#egg=django-easyfilters

